﻿/*****************************************************************************************
* File Name:	Platform.cs																 *
* Programmer:   J.T. Blevins (jt.blevins@gmail.com)										 *
* Date:         11/25/2017                                                               *
* Purpose:      A class extending the box class for use in a platformer game.			 *
*****************************************************************************************/

using SimpleGraphicsLib;
using System;
using System.Drawing;

namespace RunnerGame_CSharp
{
	/// <summary>
	/// A class extending the box class for use in a platformer game.
	/// </summary>
	/// <seealso cref="SimpleGraphicsLib.Box" />
	public class Platform : Box
	{
		private static Random random;
		public bool Scored { get; set; }


		/// <summary>
		/// Initializes a new instance of the <see cref="Platform"/> class.
		/// </summary>
		public Platform() : base()
		{
			random = new Random();
			ResetRandom( random );
			this.X = (int) ( random.Next( MainWindow.width, MainWindow.width + 2000 ) ); // Start out off-screen
		}


		/// <summary>
		/// Initializes a new instance of the <see cref="Platform"/> class.
		/// </summary>
		/// <param name="x">The x.</param>
		public Platform( int x ) : base( x )
		{
			random = new Random();
			ResetRandom( random );
			this.X = x;

		} // Constructor x


		/// <summary>
		/// Resets the platform object to random values.
		/// </summary>
		/// <param name="random">The random.</param>
		public void ResetRandom( Random random )
		{
			Scored = false;
			Height = random.Next( 30, 120 );
			Width = random.Next( 100, 500 );
			R = random.Next( 0, 200 );
			G = random.Next( 0, 200 );
			B = random.Next( 0, 200 );
			BoxColor = Color.FromArgb( R, G, B );
			Y = random.Next( MainWindow.height - MainWindow.height / 2 - Height,
				MainWindow.height - MainWindow.height / 4 - Height );

		} // ResetRandom

	} // Class

} // Namespace