﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SimpleGraphicsLib
{
	/// <summary>
	/// A class used to draw colored boxes on screen while modeling events
	/// </summary>
	public class Box
	{

		// Properties
		private Rectangle Rect { get; set; }
		private SolidBrush Brush { get; set; }
		private Graphics Graphic { get; set; }
		public Color BoxColor { get; set; }
		public int X { get; set; }
		public int Y { get; set; }
		public int Width { get; set; }
		public int Height { get; set; }
		public string Label { get; set; }
		public Font DrawFont { get; set; }
		public Brush FontBrush { get; set; }
		public PointF FontPoint { get; set; }
		public int R { get; set; }
		public int G { get; set; }
		public int B { get; set; }

		public Random Random { get; set; }
		//private Random Random;


		/// <summary>Initializes a new instance of the <see cref="Box"/> class.</summary>
		/// <param name="color">The color.</param>
		public Box()
		{
			Init( null, null );

		} // Parameterless constructor



		/// <summary>Initializes a new instance of the <see cref="Box"/> class.</summary>
		/// <param name="color">The color.</param>
		public Box( int MinX )
		{
			Init( MinX, null );

		} // Parameterless constructor



		/// <summary>Initializes a new instance of the <see cref="Box"/> class.</summary>
		/// <param name="color">The color.</param>
		public Box( Color color )
		{
			Init( null, color );

		} // Color constructor


		public Box( int x, int y )
		{
			this.X = x;
			this.Y = y;

		} // Constructor x, y


		private void Init( int? MinX, Color? color )
		{
			if( Random == null )
				Random = new Random();

			if ( color == null )
				// Assign a Random color
				color = Color.FromArgb( Random.Next( 0, 255 ), Random.Next( 0, 255 ), Random.Next( 0, 255 ) );
				//color = Color.FromArgb( 150, 150, 150 );

				if ( MinX != null )
				this.X = (int) MinX;
			else
				this.X = 100;

			this.Y = 100;
			this.Rect = new Rectangle( X, Y, Width, Height );
			this.Brush = new SolidBrush( (Color) color );
			this.BoxColor = (Color) color;
			this.Label = string.Empty;


			// Create font and brush.
			DrawFont = new Font( "Arial", 10, FontStyle.Bold );
			FontBrush = new SolidBrush( Color.FromArgb( 255-BoxColor.R, 255-BoxColor.G, 255-BoxColor.B ) );

			// Create point for upper-left corner of drawing.
			FontPoint = new PointF( 150.0F, 150.0F );

		} // Init


		/// <summary>Called when [paint].</summary>
		/// <param name="graphics">The graphics.</param>
		public virtual void OnPaint( Graphics graphics )
		{
			Label BoxLabel = new Label
			{
				Text = this.Label
			};

			Rect = new Rectangle( X, Y, Width, Height );
			using ( Brush = new SolidBrush( BoxColor ) )
			{
				graphics.FillRectangle( Brush, Rect );
			}

			// Draw string to screen.
			if ( !string.IsNullOrEmpty( this.Label ) )
				graphics.DrawString( this.Label, DrawFont, FontBrush,
					X + Width / 2 - 6, Y );//, FontPoint );

			Brush.Dispose();

		} // OnPaint


		/// <summary>Releases unmanaged and - optionally - managed resources.</summary>
		public void Dispose()
		{
			Brush.Dispose();

		} // Dispose


		/// <summary>
		/// Returns a <see cref="System.String" /> that represents this instance.
		/// </summary>
		/// <returns>A <see cref="System.String" /> that represents this instance.</returns>
		public override string ToString()
		{
			return "[X:" + X + " Y:" + Y + " W: " + Width + " H: " + Height + "]";
		}

	}
}
